/// <reference types="node" />
import * as fs from "fs";
/**
 * Additional optional options related to the channel created, for advanced usage only.
 */
export interface NodeChannelOptions {
    /**
     * The maximum number of messages that are queued up if they can't be written if I/O can't keep up,
     * before old messages are dropped. This is to assure memory remains low (assuming your messages are not insanely big).
     *
     * Normally this limit will never be reached, but if it does for some reason -
     * old messages not yet logged, are dropped (and as such won't be logged at all).
     *
     * It can happen if your application logs an extreme amount of messages in a very short time
     * and I/O itself is slow and can't keep up.
     *
     * The default is 5000 messages, you can increase it if needed. Value must be between 100 and 1000000.
     */
    maxQueuedMessages?: number;
    /**
     * When specified this function is called when a rollover occurred. It will refer to the previously completed log file.
     * If needed you can back it up and/or compress it elsewhere.
     *
     * It is recommended you deal with the file in an asynchronous fashion. Keep in mind that the file will be deleted/overwritten once the maxFiles is reached again,
     * so it may not exist anymore then (normally that should take a while, unless logging/rollover occurs at a very fast pace in which case your logging configuration
     * is probably wrong).
     */
    onRollOver?: (path: fs.PathLike) => void;
}
//# sourceMappingURL=NodeChannelOptions.d.ts.map