import { LogChannel, RawLogChannel, RawLogMessage } from "typescript-logging";
import { RetentionStrategy } from "./RetentionStrategy";
import { RetentionStrategyMaxFilesOptions } from "./RetentionStrategyMaxFilesOptions";
import { NodeChannelOptions } from "./NodeChannelOptions";
/**
 * Allows creation of various node channels that can be used to log for node to files.
 */
export declare class NodeChannelProvider {
    /**
     * Create a new LogChannel which will use given RetentionStrategy, you can use NodeChannelProvider.createRetentionStrategyMaxFiles(..) to create
     * the RetentionStrategy (or implement a custom one).
     * @param retentionStrategy The retention type
     * @param options Additional channel options
     */
    static createLogChannel(retentionStrategy: RetentionStrategy, options?: NodeChannelOptions): LogChannel;
    /**
     * Create a new RawLogChannel  which will use given RetentionStrategy, you can use NodeChannelProvider.createRetentionStrategyMaxFiles(..) to create
     * the RetentionStrategy (or implement a custom one).
     * @param retentionStrategy The retention type
     * @param writeRawLogMessage Function that does format the raw message and returns it as a string, this string is then logged in the file.
     * @param options Additional channel options
     */
    static createRawLogChannel(retentionStrategy: RetentionStrategy, writeRawLogMessage: (msg: RawLogMessage, formatArg: (arg: unknown) => string) => string, options?: NodeChannelOptions): RawLogChannel;
    /**
     * Create a new RetentionStrategy based on given options. For details please {@see RetentionStrategyMaxFilesOptions}
     * @param options
     */
    static createRetentionStrategyMaxFiles(options: RetentionStrategyMaxFilesOptions): RetentionStrategy;
}
//# sourceMappingURL=NodeChannelProvider.d.ts.map