import { NodeChannelOptions } from "../api/NodeChannelOptions";
import { RetentionStrategy } from "../api/RetentionStrategy";
import { StreamCallBack } from "./StreamCallBack";
/**
 * Base class for node channels which contains all the logic around retention and where to write to.
 */
export declare abstract class AbstractNodeChannel {
    private readonly _retentionStrategy;
    private readonly _onRollOver;
    private readonly _maxQueuedMessages;
    private _streamCallBacks;
    private _initialized;
    private _writer;
    private _writerClosed;
    protected constructor(retentionStrategy: RetentionStrategy, options?: NodeChannelOptions);
    /**
     * Forcefully close the underlying writer. Should not be used by end users, for testing purposes only. May roll over if needed.
     */
    closeWriter(): void;
    /**
     * Check whether the current writers queue is empty. Should not be used by end users, for testing purposes only.
     * @returns {boolean}
     */
    isWriterQueueEmpty(): boolean;
    /**
     * For testing purposes only, provides access to some stream events.
     * Will be applied next time a new stream is opened (not to current stream if any is open).
     *
     * @param callbacks The custom callback, when undefined unsets the callback.
     */
    setStreamCallBacks(callbacks: StreamCallBack | undefined): void;
    /**
     * Subclasses must NOT override this function, instead implement the write(...) function of the channel you implement (RawLogChannel / LogChannel), create the message
     * there and then call this method to write the actual data.
     * @param msg Message to write
     * @protected
     */
    protected writeMessage(msg: string): void;
    private initialize;
    private nextWriter;
    private onLimitReached;
    private onStreamFinished;
    private onStreamClose;
    private onStreamError;
    private onRetentionRollOver;
}
//# sourceMappingURL=AbstractNodeChannel.d.ts.map