/// <reference types="node" />
/// <reference types="node" />
import fs from "fs";
import { FileSize } from "../api/RetentionStrategy";
import { StreamCallBack } from "./StreamCallBack";
/**
 * The writer writes to a file. It has a buffer (queue) to throttle writing to the file (backpressure). The queue will throw away old messages
 * if IO can't keep up, this would only occur if there is an insane amount of logging.
 */
export declare class NodeLogWriter {
    private readonly _path;
    private readonly _encoding;
    private readonly _streamCallBack;
    private readonly _maxFileSizeInBytes;
    private readonly _onLimitReached;
    private _bytesWritten;
    private _writeStream;
    private _limitReached;
    private readonly _writeQueue;
    private _writerIsProcessing;
    private readonly _log;
    constructor(path: fs.PathLike, encoding: BufferEncoding, maxFileSize: FileSize, startFileSize: number, maxQueuedMessages: number, initialQueueBuffer: readonly string[], onLimitReached: () => void, streamCallBack: StreamCallBack);
    /**
     *  Add data to write to the queue.
     */
    write(message: string): void;
    drainRemainingBuffer(): readonly string[];
    getRemainingQueueBuffer(): readonly string[];
    isQueueEmpty(): boolean;
    close(): void;
    private processQueue;
    private getStream;
    private onError;
    private onFinished;
    private onClose;
}
//# sourceMappingURL=NodeLogWriter.d.ts.map