/**
 * Queue which has maximum size of elements. When the maximum is reached when adding a new element, it will
 * remove the old element. This is to assure we don't buffer an enormous amount of messages (causing memory problems).
 */
export declare class Queue<T> {
    private readonly _maxElementsAllowed;
    private readonly _queue;
    constructor(maxElementsAllowed: number);
    /**
     * Add a new element, when the queue is full, the oldest element is *removed* before this element is added.
     * @param {T} value
     */
    add(value: T): void;
    peekHead(): T | null;
    popHead(): T | null;
    get size(): number;
    /** Drain queue and returns all data */
    drain(): readonly T[];
    /** Get a copy of the current data */
    getData(): readonly T[];
}
//# sourceMappingURL=Queue.d.ts.map